@@ -1,8 +1,10 @@
 package Pithub::Gists;
 BEGIN {
-  $Pithub::Gists::VERSION = '0.01000';
+  $Pithub::Gists::VERSION = '0.01001';
 }
 
+# ABSTRACT: Github v3 Gists API
+
 use Moose;
 use Carp qw(croak);
 use namespace::autoclean;
@@ -10,13 +12,92 @@ extends 'Pithub::Base';
 with 'MooseX::Role::BuildInstanceOf' => { target => '::Comments' };
 around qr{^merge_.*?_args$} => \&Pithub::Base::_merge_args;
 
+
+sub create {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    return $self->request( POST => '/gists', $args{data} );
+}
+
+
+sub delete {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    return $self->request( DELETE => sprintf( '/gists/%d', $args{gist_id} ) );
+}
+
+
+sub fork {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    return $self->request( POST => sprintf( '/gists/%d/fork', $args{gist_id} ) );
+}
+
+
+sub get {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    return $self->request( GET => sprintf( '/gists/%d', $args{gist_id} ) );
+}
+
+
+sub is_starred {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    return $self->request( GET => sprintf( '/gists/%d/star', $args{gist_id} ) );
+}
+
+
+sub list {
+    my ( $self, %args ) = @_;
+    if ( my $user = $args{user} ) {
+        return $self->request( GET => sprintf( '/users/%s/gists', $user ) );
+    }
+    elsif ( $args{starred} ) {
+        return $self->request( GET => '/gists/starred' );
+    }
+    elsif ( $args{public} ) {
+        return $self->request( GET => '/gists/public' );
+    }
+    return $self->request( GET => '/gists' );
+}
+
+
+sub star {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    return $self->request( PUT => sprintf( '/gists/%d/star', $args{gist_id} ) );
+}
+
+
+sub unstar {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    return $self->request( DELETE => sprintf( '/gists/%d/star', $args{gist_id} ) );
+}
+
+
+sub update {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    return $self->request( PATCH => sprintf( '/gists/%d', $args{gist_id} ), $args{data} );
+}
+
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
-Pithub::Gists
+Pithub::Gists - Github v3 Gists API
 
 =head1 VERSION
 
-version 0.01000
+version 0.01001
 
 =head1 METHODS
 
@@ -34,7 +115,7 @@ Create a gist
 
 Examples:
 
-    my $result = $p->gists->create(
+    $result = $p->gists->create(
         data => {
             description => 'the description for this gist',
             public      => 1,
@@ -42,14 +123,6 @@ Examples:
         }
     );
 
-=cut
-
-sub create {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( POST => '/gists', $args{data} );
-}
-
 =head2 delete
 
 =over
@@ -66,14 +139,6 @@ Examples:
 
     $result = $p->gists->delete( gist_id => 784612 );
 
-=cut
-
-sub delete {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    return $self->request( DELETE => sprintf( '/gists/%d', $args{gist_id} ) );
-}
-
 =head2 fork
 
 =over
@@ -90,14 +155,6 @@ Examples:
 
     $result = $p->gists->fork( gist_id => 784612 );
 
-=cut
-
-sub fork {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    return $self->request( POST => sprintf( '/gists/%d/fork', $args{gist_id} ) );
-}
-
 =head2 get
 
 =over
@@ -114,14 +171,6 @@ Examples:
 
     $result = $p->gists->get( gist_id => 784612 );
 
-=cut
-
-sub get {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    return $self->request( GET => sprintf( '/gists/%d', $args{gist_id} ) );
-}
-
 =head2 is_starred
 
 =over
@@ -138,14 +187,6 @@ Examples:
 
     $result = $p->gists->is_starred( gist_id => 784612 );
 
-=cut
-
-sub is_starred {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    return $self->request( GET => sprintf( '/gists/%d/star', $args{gist_id} ) );
-}
-
 =head2 list
 
 =over
@@ -192,22 +233,6 @@ Examples:
     # List all public gists:
     $result = $p->gists->list( public => 1 );
 
-=cut
-
-sub list {
-    my ( $self, %args ) = @_;
-    if ( my $user = $args{user} ) {
-        return $self->request( GET => sprintf( '/users/%s/gists', $user ) );
-    }
-    elsif ( $args{starred} ) {
-        return $self->request( GET => '/gists/starred' );
-    }
-    elsif ( $args{public} ) {
-        return $self->request( GET => '/gists/public' );
-    }
-    return $self->request( GET => '/gists' );
-}
-
 =head2 star
 
 =over
@@ -224,14 +249,6 @@ Examples:
 
     $result = $p->gists->star( gist_id => 784612 );
 
-=cut
-
-sub star {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    return $self->request( PUT => sprintf( '/gists/%d/star', $args{gist_id} ) );
-}
-
 =head2 unstar
 
 =over
@@ -248,14 +265,6 @@ Examples:
 
     $result = $p->gists->unstar( gist_id => 784612 );
 
-=cut
-
-sub unstar {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    return $self->request( DELETE => sprintf( '/gists/%d/star', $args{gist_id} ) );
-}
-
 =head2 update
 
 =over
@@ -270,20 +279,21 @@ Edit a gist
 
 Examples:
 
-    my $result = $p->gists->update(
+    $result = $p->gists->update(
         gist_id => 784612,
         data    => { description => 'bar foo' }
     );
 
+=head1 AUTHOR
+
+Johannes Plunien <plu@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Johannes Plunien.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub update {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( PATCH => sprintf( '/gists/%d', $args{gist_id} ), $args{data} );
-}
-
-__PACKAGE__->meta->make_immutable;
-
-1;
