@@ -1,20 +1,66 @@
 package Pithub::Gists::Comments;
 BEGIN {
-  $Pithub::Gists::Comments::VERSION = '0.01000';
+  $Pithub::Gists::Comments::VERSION = '0.01001';
 }
 
+# ABSTRACT: Github v3 Gist Comments API
+
 use Moose;
 use Carp qw(croak);
 use namespace::autoclean;
 extends 'Pithub::Base';
 
+
+sub create {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    return $self->request( POST => sprintf( '/gists/%d/comments', $args{gist_id} ), $args{data} );
+}
+
+
+sub delete {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
+    return $self->request( DELETE => sprintf( '/gists/comments/%d', $args{comment_id} ) );
+}
+
+
+sub get {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
+    return $self->request( GET => sprintf( '/gists/comments/%d', $args{comment_id} ) );
+}
+
+
+sub list {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
+    return $self->request( GET => sprintf( '/gists/%d/comments', $args{gist_id} ) );
+}
+
+
+sub update {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    return $self->request( PATCH => sprintf( '/gists/comments/%d', $args{comment_id} ), $args{data} );
+}
+
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
-Pithub::Gists::Comments
+Pithub::Gists::Comments - Github v3 Gist Comments API
 
 =head1 VERSION
 
-version 0.01000
+version 0.01001
 
 =head1 METHODS
 
@@ -37,15 +83,6 @@ Examples:
         data    => { body => 'some comment' },
     );
 
-=cut
-
-sub create {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( POST => sprintf( '/gists/%d/comments', $args{gist_id} ), $args{data} );
-}
-
 =head2 delete
 
 =over
@@ -62,14 +99,6 @@ Examples:
 
     $result = $p->gists->comments->delete( comment_id => 1 );
 
-=cut
-
-sub delete {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    return $self->request( DELETE => sprintf( '/gists/comments/%d', $args{comment_id} ) );
-}
-
 =head2 get
 
 =over
@@ -86,14 +115,6 @@ Examples:
 
     $result = $p->gists->comments->get( comment_id => 1 );
 
-=cut
-
-sub get {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    return $self->request( GET => sprintf( '/gists/comments/%d', $args{comment_id} ) );
-}
-
 =head2 list
 
 =over
@@ -110,14 +131,6 @@ Examples:
 
     $result = $p->gists->comments->list( gist_id => 1 );
 
-=cut
-
-sub list {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: gist_id' unless $args{gist_id};
-    return $self->request( GET => sprintf( '/gists/%d/comments', $args{gist_id} ) );
-}
-
 =head2 update
 
 =over
@@ -137,15 +150,16 @@ Examples:
         data       => { body => 'some comment' }
     );
 
+=head1 AUTHOR
+
+Johannes Plunien <plu@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Johannes Plunien.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub update {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( PATCH => sprintf( '/gists/comments/%d', $args{comment_id} ), $args{data} );
-}
-
-__PACKAGE__->meta->make_immutable;
-
-1;
