@@ -1,20 +1,53 @@
 package Pithub::GitData::Trees;
 BEGIN {
-  $Pithub::GitData::Trees::VERSION = '0.01000';
+  $Pithub::GitData::Trees::VERSION = '0.01001';
 }
 
+# ABSTRACT: Github v3 Git Data Trees API
+
 use Moose;
 use Carp qw(croak);
 use namespace::autoclean;
 extends 'Pithub::Base';
 
+
+sub create {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( POST => sprintf( '/repos/%s/%s/git/trees', $args{user}, $args{repo} ), $args{data} );
+}
+
+
+sub get {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: sha' unless $args{sha};
+    $self->_validate_user_repo_args( \%args );
+    my $path = sprintf( '/repos/%s/%s/git/trees/%s', $args{user}, $args{repo}, $args{sha} );
+    my $options = {};
+    if ( $args{recursive} ) {
+        $options->{prepare_uri} = sub {
+            my ($uri) = @_;
+            $uri->query_form( recursive => 1 );
+        };
+    }
+    return $self->request( GET => $path, undef, $options );
+}
+
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
-Pithub::GitData::Trees
+Pithub::GitData::Trees - Github v3 Git Data Trees API
 
 =head1 VERSION
 
-version 0.01000
+version 0.01001
 
 =head1 METHODS
 
@@ -88,15 +121,6 @@ Use either this or tree.sha
 
 =back
 
-=cut
-
-sub create {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( POST => sprintf( '/repos/%s/%s/git/trees', $args{user}, $args{repo} ), $args{data} );
-}
-
 =head2 get
 
 =over
@@ -130,23 +154,16 @@ Get a Tree Recursively
         recursive => 1,
     );
 
+=head1 AUTHOR
+
+Johannes Plunien <plu@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Johannes Plunien.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub get {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: sha' unless $args{sha};
-    $self->_validate_user_repo_args( \%args );
-    my $path = sprintf( '/repos/%s/%s/git/trees/%s', $args{user}, $args{repo}, $args{sha} );
-    my $options = {};
-    if ( $args{recursive} ) {
-        $options->{prepare_uri} = sub {
-            my ($uri) = @_;
-            $uri->query_form( recursive => 1 );
-        };
-    }
-    return $self->request( GET => $path, undef, $options );
-}
-
-__PACKAGE__->meta->make_immutable;
-
-1;
