@@ -1,20 +1,71 @@
 package Pithub::PullRequests::Comments;
 BEGIN {
-  $Pithub::PullRequests::Comments::VERSION = '0.01000';
+  $Pithub::PullRequests::Comments::VERSION = '0.01001';
 }
 
+# ABSTRACT: Github v3 Pull Request Comments API
+
 use Moose;
 use Carp qw(croak);
 use namespace::autoclean;
 extends 'Pithub::Base';
 
+
+sub create {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( POST => sprintf( '/repos/%s/%s/pulls/%d/comments', $args{user}, $args{repo}, $args{pull_request_id} ), $args{data} );
+}
+
+
+sub delete {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( DELETE => sprintf( '/repos/%s/%s/pulls/comments/%d', $args{user}, $args{repo}, $args{comment_id} ) );
+}
+
+
+sub get {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( GET => sprintf( '/repos/%s/%s/pulls/comments/%d', $args{user}, $args{repo}, $args{comment_id} ) );
+}
+
+
+sub list {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( GET => sprintf( '/repos/%s/%s/pulls/%d/comments', $args{user}, $args{repo}, $args{pull_request_id} ) );
+}
+
+
+sub update {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( PATCH => sprintf( '/repos/%s/%s/pulls/comments/%d', $args{user}, $args{repo}, $args{comment_id} ), $args{data} );
+}
+
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
-Pithub::PullRequests::Comments
+Pithub::PullRequests::Comments - Github v3 Pull Request Comments API
 
 =head1 VERSION
 
-version 0.01000
+version 0.01001
 
 =head1 METHODS
 
@@ -44,16 +95,6 @@ Examples:
         }
     );
 
-=cut
-
-sub create {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( POST => sprintf( '/repos/%s/%s/pulls/%d/comments', $args{user}, $args{repo}, $args{pull_request_id} ), $args{data} );
-}
-
 =head2 delete
 
 =over
@@ -74,15 +115,6 @@ Examples:
         comment_id => 1,
     );
 
-=cut
-
-sub delete {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( DELETE => sprintf( '/repos/%s/%s/pulls/comments/%d', $args{user}, $args{repo}, $args{comment_id} ) );
-}
-
 =head2 get
 
 =over
@@ -103,15 +135,6 @@ Examples:
         comment_id => 1,
     );
 
-=cut
-
-sub get {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( GET => sprintf( '/repos/%s/%s/pulls/comments/%d', $args{user}, $args{repo}, $args{comment_id} ) );
-}
-
 =head2 list
 
 =over
@@ -132,15 +155,6 @@ Examples:
         pull_request_id => 1,
     );
 
-=cut
-
-sub list {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( GET => sprintf( '/repos/%s/%s/pulls/%d/comments', $args{user}, $args{repo}, $args{pull_request_id} ) );
-}
-
 =head2 update
 
 =over
@@ -162,16 +176,16 @@ Examples:
         data       => { body => 'some updated comment' },
     );
 
+=head1 AUTHOR
+
+Johannes Plunien <plu@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Johannes Plunien.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub update {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( PATCH => sprintf( '/repos/%s/%s/pulls/comments/%d', $args{user}, $args{repo}, $args{comment_id} ), $args{data} );
-}
-
-__PACKAGE__->meta->make_immutable;
-
-1;
