@@ -1,20 +1,60 @@
 package Pithub::Repos::Collaborators;
 BEGIN {
-  $Pithub::Repos::Collaborators::VERSION = '0.01000';
+  $Pithub::Repos::Collaborators::VERSION = '0.01001';
 }
 
+# ABSTRACT: Github v3 Repo Collaborators API
+
 use Moose;
 use Carp qw(croak);
 use namespace::autoclean;
 extends 'Pithub::Base';
 
+
+sub add {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( PUT => sprintf( '/repos/%s/%s/collaborators/%s', $args{user}, $args{repo}, $args{collaborator} ) );
+}
+
+
+sub is_collaborator {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( GET => sprintf( '/repos/%s/%s/collaborators/%s', $args{user}, $args{repo}, $args{collaborator} ) );
+}
+
+
+sub list {
+    my ( $self, %args ) = @_;
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( GET => sprintf( '/repos/%s/%s/collaborators', $args{user}, $args{repo} ) );
+}
+
+
+sub remove {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( DELETE => sprintf( '/repos/%s/%s/collaborators/%s', $args{user}, $args{repo}, $args{collaborator} ) );
+}
+
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
-Pithub::Repos::Collaborators
+Pithub::Repos::Collaborators - Github v3 Repo Collaborators API
 
 =head1 VERSION
 
-version 0.01000
+version 0.01001
 
 =head1 METHODS
 
@@ -38,15 +78,6 @@ Examples:
         collaborator => 'rbo',
     );
 
-=cut
-
-sub add {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( PUT => sprintf( '/repos/%s/%s/collaborators/%s', $args{user}, $args{repo}, $args{collaborator} ) );
-}
-
 =head2 is_collaborator
 
 =over
@@ -74,15 +105,6 @@ Examples:
         print "rbo is not added as collaborator to Pithub\n";
     }
 
-=cut
-
-sub is_collaborator {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( GET => sprintf( '/repos/%s/%s/collaborators/%s', $args{user}, $args{repo}, $args{collaborator} ) );
-}
-
 =head2 list
 
 =over
@@ -102,14 +124,6 @@ Examples:
         repo => 'Pithub',
     );
 
-=cut
-
-sub list {
-    my ( $self, %args ) = @_;
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( GET => sprintf( '/repos/%s/%s/collaborators', $args{user}, $args{repo} ) );
-}
-
 =head2 remove
 
 =over
@@ -124,21 +138,22 @@ Remove collaborator
 
 Examples:
 
-    my $result = $p->repos->collaborators->remove(
+    $result = $p->repos->collaborators->remove(
         user         => 'plu',
         repo         => 'Pithub',
         collaborator => 'rbo',
     );
 
+=head1 AUTHOR
+
+Johannes Plunien <plu@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Johannes Plunien.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub remove {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( DELETE => sprintf( '/repos/%s/%s/collaborators/%s', $args{user}, $args{repo}, $args{collaborator} ) );
-}
-
-__PACKAGE__->meta->make_immutable;
-
-1;
