@@ -1,20 +1,66 @@
 package Pithub::Repos::Watching;
 BEGIN {
-  $Pithub::Repos::Watching::VERSION = '0.01000';
+  $Pithub::Repos::Watching::VERSION = '0.01001';
 }
 
+# ABSTRACT: Github v3 Repo Watching API
+
 use Moose;
 use Carp qw(croak);
 use namespace::autoclean;
 extends 'Pithub::Base';
 
+
+sub is_watching {
+    my ( $self, %args ) = @_;
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( GET => sprintf( '/user/watched/%s/%s', $args{user}, $args{repo} ) );
+}
+
+
+sub list_repos {
+    my ( $self, %args ) = @_;
+    if ( my $user = $args{user} ) {
+        return $self->request( GET => sprintf( '/users/%s/watched', $args{user} ) );
+    }
+    return $self->request( GET => '/user/watched' );
+}
+
+
+sub list {
+    my ( $self, %args ) = @_;
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( GET => sprintf( '/repos/%s/%s/watchers', $args{user}, $args{repo} ) );
+}
+
+
+sub start_watching {
+    my ( $self, %args ) = @_;
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( PUT => sprintf( '/user/watched/%s/%s', $args{user}, $args{repo} ) );
+}
+
+
+sub stop_watching {
+    my ( $self, %args ) = @_;
+    $self->_validate_user_repo_args( \%args );
+    return $self->request( DELETE => sprintf( '/user/watched/%s/%s', $args{user}, $args{repo} ) );
+}
+
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
-Pithub::Repos::Watching
+Pithub::Repos::Watching - Github v3 Repo Watching API
 
 =head1 VERSION
 
-version 0.01000
+version 0.01001
 
 =head1 METHODS
 
@@ -37,14 +83,6 @@ Examples:
         user => 'plu',
     );
 
-=cut
-
-sub is_watching {
-    my ( $self, %args ) = @_;
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( GET => sprintf( '/user/watched/%s/%s', $args{user}, $args{repo} ) );
-}
-
 =head2 list_repos
 
 =over
@@ -71,16 +109,6 @@ Examples:
 
 =back
 
-=cut
-
-sub list_repos {
-    my ( $self, %args ) = @_;
-    if ( my $user = $args{user} ) {
-        return $self->request( GET => sprintf( '/users/%s/watched', $args{user} ) );
-    }
-    return $self->request( GET => '/user/watched' );
-}
-
 =head2 list
 
 =over
@@ -100,14 +128,6 @@ Examples:
         repo => 'Pithub',
     );
 
-=cut
-
-sub list {
-    my ( $self, %args ) = @_;
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( GET => sprintf( '/repos/%s/%s/watchers', $args{user}, $args{repo} ) );
-}
-
 =head2 start_watching
 
 =over
@@ -127,14 +147,6 @@ Examples:
         repo => 'Pithub',
     );
 
-=cut
-
-sub start_watching {
-    my ( $self, %args ) = @_;
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( PUT => sprintf( '/user/watched/%s/%s', $args{user}, $args{repo} ) );
-}
-
 =head2 stop_watching
 
 =over
@@ -154,14 +166,16 @@ Examples:
         repo => 'Pithub',
     );
 
+=head1 AUTHOR
+
+Johannes Plunien <plu@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Johannes Plunien.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub stop_watching {
-    my ( $self, %args ) = @_;
-    $self->_validate_user_repo_args( \%args );
-    return $self->request( DELETE => sprintf( '/user/watched/%s/%s', $args{user}, $args{repo} ) );
-}
-
-__PACKAGE__->meta->make_immutable;
-
-1;
