@@ -1,29 +1,15 @@
 package Pithub::Result;
 BEGIN {
-  $Pithub::Result::VERSION = '0.01000';
+  $Pithub::Result::VERSION = '0.01001';
 }
 
+# ABSTRACT: Github v3 result object
+
 use Moose;
 use JSON::Any;
 use URI;
 use namespace::autoclean;
 
-=head1 NAME
-
-Pithub::Result
-
-=head1 VERSION
-
-version 0.01000
-
-=head1 ATTRIBUTES
-
-=head2 content
-
-The decoded JSON response. May be an arrayref or hashref, depending
-on the API call.
-
-=cut
 
 has 'content' => (
     is         => 'ro',
@@ -31,12 +17,6 @@ has 'content' => (
     lazy_build => 1,
 );
 
-=head2 first_page_uri
-
-The extracted value from the C<< Link >> header for the first page.
-This can return undef.
-
-=cut
 
 has 'first_page_uri' => (
     is         => 'ro',
@@ -44,12 +24,6 @@ has 'first_page_uri' => (
     lazy_build => 1,
 );
 
-=head2 last_page_uri
-
-The extracted value from the C<< Link >> header for the last page.
-This can return undef.
-
-=cut
 
 has 'last_page_uri' => (
     is         => 'ro',
@@ -57,12 +31,6 @@ has 'last_page_uri' => (
     lazy_build => 1,
 );
 
-=head2 next_page_uri
-
-The extracted value from the C<< Link >> header for the next page.
-This can return undef.
-
-=cut
 
 has 'next_page_uri' => (
     is         => 'ro',
@@ -70,12 +38,6 @@ has 'next_page_uri' => (
     lazy_build => 1,
 );
 
-=head2 prev_page_uri
-
-The extracted value from the C<< Link >> header for the previous
-page. This can return undef.
-
-=cut
 
 has 'prev_page_uri' => (
     is         => 'ro',
@@ -83,32 +45,6 @@ has 'prev_page_uri' => (
     lazy_build => 1,
 );
 
-=head2 response
-
-The L<Pithub::Response> object. There are following delegate methods
-installed for convenience:
-
-=over
-
-=item *
-
-B<code>: response->code
-
-=item *
-
-B<raw_content>: response->content
-
-=item *
-
-B<request>: response->request
-
-=item *
-
-B<success>: response->success
-
-=back
-
-=cut
 
 has 'response' => (
     handles => {
@@ -135,15 +71,6 @@ has '_json' => (
     lazy_build => 1,
 );
 
-=head1 METHODS
-
-=head2 first_page
-
-Get the L<Pithub::Result> of the first page. Returns undef if there
-is no first page (if you're on the first page already or if there
-is no pages at all).
-
-=cut
 
 sub first_page {
     my ($self) = @_;
@@ -151,13 +78,6 @@ sub first_page {
     return $self->_paginate( $self->first_page_uri );
 }
 
-=head2 last_page
-
-Get the L<Pithub::Result> of the last page. Returns undef if there
-is no last page (if you're on the last page already or if there
-is only one page or no pages at all).
-
-=cut
 
 sub last_page {
     my ($self) = @_;
@@ -165,36 +85,6 @@ sub last_page {
     return $self->_paginate( $self->last_page_uri );
 }
 
-=head2 next_page
-
-Get the L<Pithub::Result> of the next page. Returns undef if there
-is no next page (there's only one page at all).
-
-Examples:
-
-=over
-
-=item *
-
-List all followers in order, from the first one on the first
-page to the last one on the last page.
-
-    $followers = Pithub->new->users->followers;
-    $result = $followers->list( user => 'rjbs' );
-    do {
-        if ( $result->success ) {
-            foreach my $row ( @{ $result->content } ) {
-                printf "%s\n", $row->{login};
-            }
-        }
-    } while $result = $result->next_page;
-
-The nature of the implementation requires you here to do a
-C<< do { ... } while ... >> loop.
-
-=back
-
-=cut
 
 sub next_page {
     my ($self) = @_;
@@ -202,33 +92,6 @@ sub next_page {
     return $self->_paginate( $self->next_page_uri );
 }
 
-=head2 prev_page
-
-Get the L<Pithub::Result> of the previous page. Returns undef if there
-is no previous page (you're on the first page).
-
-Examples:
-
-=over
-
-=item *
-
-List all followers in reverse order, from the last one on the last
-page to the first one on the first page.
-
-    $followers = Pithub->new->users->followers;
-    $result = $followers->list( user => 'rjbs' )->last_page;    # this makes two requests!
-    do {
-        if ( $result->success ) {
-            foreach my $row ( reverse @{ $result->content } ) {
-                printf "%s\n", $row->{login};
-            }
-        }
-    } while $result = $result->prev_page;
-
-=back
-
-=cut
 
 sub prev_page {
     my ($self) = @_;
@@ -236,22 +99,12 @@ sub prev_page {
     return $self->_paginate( $self->prev_page_uri );
 }
 
-=head2 ratelimit
-
-Returns the value of the C<< X-Ratelimit-Limit >> http header.
-
-=cut
 
 sub ratelimit {
     my ($self) = @_;
     return $self->response->http_response->header('X-RateLimit-Limit');
 }
 
-=head2 ratelimit_remaining
-
-Returns the value of the C<< X-Ratelimit-Remaining >> http header.
-
-=cut
 
 sub ratelimit_remaining {
     my ($self) = @_;
@@ -310,3 +163,157 @@ sub _paginate {
 __PACKAGE__->meta->make_immutable;
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Pithub::Result - Github v3 result object
+
+=head1 VERSION
+
+version 0.01001
+
+=head1 ATTRIBUTES
+
+=head2 content
+
+The decoded JSON response. May be an arrayref or hashref, depending
+on the API call.
+
+=head2 first_page_uri
+
+The extracted value from the C<< Link >> header for the first page.
+This can return undef.
+
+=head2 last_page_uri
+
+The extracted value from the C<< Link >> header for the last page.
+This can return undef.
+
+=head2 next_page_uri
+
+The extracted value from the C<< Link >> header for the next page.
+This can return undef.
+
+=head2 prev_page_uri
+
+The extracted value from the C<< Link >> header for the previous
+page. This can return undef.
+
+=head2 response
+
+The L<Pithub::Response> object. There are following delegate methods
+installed for convenience:
+
+=over
+
+=item *
+
+B<code>: response->code
+
+=item *
+
+B<raw_content>: response->content
+
+=item *
+
+B<request>: response->request
+
+=item *
+
+B<success>: response->success
+
+=back
+
+=head1 METHODS
+
+=head2 first_page
+
+Get the L<Pithub::Result> of the first page. Returns undef if there
+is no first page (if you're on the first page already or if there
+is no pages at all).
+
+=head2 last_page
+
+Get the L<Pithub::Result> of the last page. Returns undef if there
+is no last page (if you're on the last page already or if there
+is only one page or no pages at all).
+
+=head2 next_page
+
+Get the L<Pithub::Result> of the next page. Returns undef if there
+is no next page (there's only one page at all).
+
+Examples:
+
+=over
+
+=item *
+
+List all followers in order, from the first one on the first
+page to the last one on the last page.
+
+    $followers = Pithub->new->users->followers;
+    $result = $followers->list( user => 'rjbs' );
+    do {
+        if ( $result->success ) {
+            foreach my $row ( @{ $result->content } ) {
+                printf "%s\n", $row->{login};
+            }
+        }
+    } while $result = $result->next_page;
+
+The nature of the implementation requires you here to do a
+C<< do { ... } while ... >> loop.
+
+=back
+
+=head2 prev_page
+
+Get the L<Pithub::Result> of the previous page. Returns undef if there
+is no previous page (you're on the first page).
+
+Examples:
+
+=over
+
+=item *
+
+List all followers in reverse order, from the last one on the last
+page to the first one on the first page.
+
+    $followers = Pithub->new->users->followers;
+    $result = $followers->list( user => 'rjbs' )->last_page;    # this makes two requests!
+    do {
+        if ( $result->success ) {
+            foreach my $row ( reverse @{ $result->content } ) {
+                printf "%s\n", $row->{login};
+            }
+        }
+    } while $result = $result->prev_page;
+
+=back
+
+=head2 ratelimit
+
+Returns the value of the C<< X-Ratelimit-Limit >> http header.
+
+=head2 ratelimit_remaining
+
+Returns the value of the C<< X-Ratelimit-Remaining >> http header.
+
+=head1 AUTHOR
+
+Johannes Plunien <plu@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Johannes Plunien.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
