@@ -1,20 +1,64 @@
 package Pithub::Users::Keys;
 BEGIN {
-  $Pithub::Users::Keys::VERSION = '0.01000';
+  $Pithub::Users::Keys::VERSION = '0.01001';
 }
 
+# ABSTRACT: Github v3 User Keys API
+
 use Moose;
 use Carp qw(croak);
 use namespace::autoclean;
 extends 'Pithub::Base';
 
+
+sub create {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    return $self->request( POST => '/user/keys', $args{data} );
+}
+
+
+sub delete {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: key_id' unless $args{key_id};
+    return $self->request( DELETE => sprintf( '/user/keys/%d', $args{key_id} ) );
+}
+
+
+sub get {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: key_id' unless $args{key_id};
+    return $self->request( GET => sprintf( '/user/keys/%d', $args{key_id} ) );
+}
+
+
+sub list {
+    my ($self) = @_;
+    return $self->request( GET => '/user/keys' );
+}
+
+
+sub update {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: key_id' unless $args{key_id};
+    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    return $self->request( PATCH => sprintf( '/user/keys/%d', $args{key_id} ), $args{data} );
+}
+
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
+=pod
+
 =head1 NAME
 
-Pithub::Users::Keys
+Pithub::Users::Keys - Github v3 User Keys API
 
 =head1 VERSION
 
-version 0.01000
+version 0.01001
 
 =head1 METHODS
 
@@ -48,14 +92,6 @@ Examples:
         }
     );
 
-=cut
-
-sub create {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( POST => '/user/keys', $args{data} );
-}
-
 =head2 delete
 
 =over
@@ -76,14 +112,6 @@ Examples:
     $k = Pithub::Users::Keys->new( token => 'b3c62c6' );
     $result = $k->delete( key_id => 123 );
 
-=cut
-
-sub delete {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: key_id' unless $args{key_id};
-    return $self->request( DELETE => sprintf( '/user/keys/%d', $args{key_id} ) );
-}
-
 =head2 get
 
 =over
@@ -104,14 +132,6 @@ Examples:
     $k = Pithub::Users::Keys->new( token => 'b3c62c6' );
     $result = $k->get( key_id => 123 );
 
-=cut
-
-sub get {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: key_id' unless $args{key_id};
-    return $self->request( GET => sprintf( '/user/keys/%d', $args{key_id} ) );
-}
-
 =head2 list
 
 =over
@@ -132,13 +152,6 @@ Examples:
     $k = Pithub::Users::Keys->new( token => 'b3c62c6' );
     $result = $k->list;
 
-=cut
-
-sub list {
-    my ($self) = @_;
-    return $self->request( GET => '/user/keys' );
-}
-
 =head2 update
 
 =over
@@ -171,15 +184,16 @@ Examples:
         }
     );
 
+=head1 AUTHOR
+
+Johannes Plunien <plu@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Johannes Plunien.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-sub update {
-    my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: key_id' unless $args{key_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( PATCH => sprintf( '/user/keys/%d', $args{key_id} ), $args{data} );
-}
-
-__PACKAGE__->meta->make_immutable;
-
-1;
